@@ -5,6 +5,10 @@ import sys
 import os
 import shutil
 import psutil
+import unicodedata
+from datetime import datetime
+from random import randint
+from docx import Document
 from openpyxl.utils import column_index_from_string
 from datetime import datetime
 
@@ -257,4 +261,77 @@ def WriteToExcelFile(filename, sheetname, data_value, row_index, col_index):
      ws.cell(row=r, column=c).value = ''
      ws.cell(row=r, column=c).value = data_value    #enter the data_value in cell row=r and column=c
 
-     wb.save(filename) # Save the workbook
\ No newline at end of file
+     wb.save(filename) # Save the workbook
+
+def ReplaceAccents(text):
+
+    """
+    Replaces French accents with the same characters but without accents 
+    """
+
+    try:
+        text = unicode(text, 'utf-8')
+    except NameError: # unicode is a default on python 3
+        pass
+    text = unicodedata.normalize('NFD', text)\
+           .encode('ascii', 'ignore')\
+           .decode("utf-8")
+    return str(text)
+
+
+def ReadWordFile(path): 
+
+    """
+    Reads the text from a MS Word file and returns the text 
+    """  
+    document = Document(path)
+    for para in document.paragraphs:
+       return (para.text)
+
+
+def RandomNumber(num_digits):
+
+    """
+    Generates a random number having the number of digits inputted in parameter "num_digits" 
+    """ 
+    n = int(num_digits)
+
+    range_start = 10**(n-1)
+
+    range_end = (10**n)-1
+
+    return randint(range_start, range_end)
+
+ 
+
+def RunRFTestSuite(project_dir, ts_name, ts_subfolders, browser_var, env_var, lang_var, run_type_var, tc_row_index_var):
+
+    """
+    Runs a Robot Framework Test Suite and moves the test result files to the Reports
+    folder relevant to the project main folder (parameter: project_dir) for a given
+    test suite (parameters: ts_name), test suite subfolders (parameter: ts_subfolders), and variables
+    (paraemeters: browser_var, env_var, lang_var, tc_row_index_var)
+    
+    Note:  Based on the Robot Framework Project Folder template structure
+
+    """
+
+    current_date_time = datetime.now()
+    timestamp = current_date_time.strftime("%Y%m%d")
+    change_dir = "cd " + project_dir
+
+    a = "robot -d "
+    b = "Reports" + "\\" + "\\" + ts_name + "-" + timestamp + " --timestampoutputs -r "
+    c = "_reports.html -o "
+    d = "_output.xml -l "
+    e = "_log.html "
+    f = "--variable browser:" + browser_var + " --variable environment_to_run_test:" + env_var + " --variable lang:" + lang_var + " --variable run_type:" + run_type_var + " --variable test_case_row_index:" + tc_row_index_var + " "
+    g = ts_subfolders + "\\" + ts_name + ".robot"
+
+    cmds = a + b + ts_name + c + ts_name + d + ts_name + e + f + g
+
+    print(cmds)
+
+    os.system(change_dir)
+
+    os.system(cmds)
\ No newline at end of file
